==> mauticGIT-Test-20251212_104643.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/f3/f3a763a9d8ba284d59471d00f19b3f8b.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/NotificationBundle/Assets/img/OneSignal.png */
class __TwigTemplate_9e765908843e27e3aceb4d276693f52c extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000\000\000\000\000\000\000>a\000\000\$FIDATx]e>\"`AQZ(RػݝfA&EJC0D  (J\t\tHH){w!\$\$tw{;{RngPW_~կUW_kUHjYv<OܷyW|n.Ϸ{}_*w~PO3Jܦ;PkyCç56Wpl{/lDs֧Euuo6=^P\000gCpf@qAO17\\sV#6,k|:xV<;W9̌Tys`/?n06klv`Mn).Iܥk[K\"spC#x!Nظľ}ׯ\\U{[Z&v<e2#BƼE͘S
{xx2T0gk.t`6Ǩ6hd6)LfIb`{kKsp;jg3noM\t?V>j/cSpC])}?и`ߒ7Z\0004Q3z\$pk9Ƴݽ7]Mu<T+XRlD搼NM~+\000SS}[](DshuZ-6_,@+d&۟MpͧCǜXuhW]<t\"S܊nú,^/85Z{6/:v;mgsI'P68
\000,ZohJ4</lO_!>a
w~ّ^\000tzۂR?C=lS\$/clu%kӆ#E2AGCq:KM67ڔO>6@ZolYPdẍLsz*ǩUz.ohY0곾`'6Ң5g'_=82yt|\"`1KڞrG,]X3r37*T8GZ?n
|WRr}m^V=em31bͨ}ys{[AT/o^K!Je2{Rz]/'S/P%mޠPAzpφç<XW2+0_}:qSꇈ︿](wW˯.bg\"Z@{V
(Uw:&ζRot\000Qx-x5&ខIP\tunnp.KV֨cKO-UAu4
ޭPO6o=G_8cN2?pE>Z
/~yWJxp\tI W6#u8'pl`LA9p)OڦɳmCs}k4>sr
ZR[2DYw&mɏ!6oL.'l?iw1LTM;d}ɠugc!NiB9\" :\t\\ABV)d%\"s6ǐH(8L;,B!4) :G2g.+37ƽ}vosu5ZR?IlJ2h6ӳځ@~\$~բ\0000H+IU1el@Ah=g6/NMRivٱGMѻewt+C>Q7\"[!Vuqu˜VmǷL#N6f[2Y.߇1./zL\"foYGw47oU1hYl(FI'V|=/7Y6S~OsxYqshB8Ċl\$w'+0.j6=~XHm :(Uro:Sn:l\tN,+o;llͺ3ɴPPk~ȸCkv
ZͦUp<X)9D>pj'Xֆ=)|_[zEOa^-mGGx~G#a(5\"3\\\t%O0RQzjk6b]I4Q1,?{zI<e8aVȨ
:w|e|l1wgE谬[<r\"\t2smU`/l#aʪR킭e̝T:\\}tm2sh&\\Ӛg(LC_4jDb^_rB\000Jd
JȞl\000%6oni}iڙa
b\000B`&7x~:#:d#;9,u[\000^0pfDuob0N?y;,PwQoWvg-My[](JGXX
w6
^\\l툫ZIq,61cY
>ṇI`xZTj?z&8QD|eބ3-<q%lI6m>Er_SkkWnv@}iC1O\000rP\\,81SɚCx}Ο|tdWL6:u<fQqRPÙ&Zʙm~U6
6g<j;:|_O*@鸎oS55A43
~sp\\m!C?<fIQY&,[ʼB'զy[N{\$kݎMhDH6a5Ę\"u^!1ܧ2)rsQICxI6U]63*;X6%) !S\"f=\$ٓ^z8*a\tT1xq+\t+Xhjyu\000hӉgx
!dԴ##)%췸\tWY)\$WOѲvٸ&)`Evwۘ`Ώsz͏l+(KK0nMĘR_A*If`جv\t45Ԅ>
?LX\000x'osSh\"ݰ®Bu%WAl{7,/cϚH5[J~?sΟe%(rfŦsA/gn<N:Bpݵ/NFh>Ƣݴz
xpV;Ew`T46/)e
kPT*+Ԏ>@%\tz\tkT3\tRSGܚ0*gŦPz6v)m,;p~C
2pkeu|@s%9ܼ6\$cnIA;0;'\$5r
ܬ\$?B**,D5ƓY÷
+ \">/\\CRlߏe\t]*:hзD4d!'=m^'q#\000CƳR/rz;ߣtڠ)k'=2=ͿH1{ȓڣ*R5\$20S\"oLOBe.'Gp8ԼQpy.%C@ʻt\000{Ήx4\\dXy{
*:f-~>P?vZ4`;=-[iXZ\\639-fg.JIoe_0B
LkK!f@R;|]I!DG-2 zjZ&K\"OG7M8-S<²
?5\000B7;r\tr\"\000J /MÑ#Cّx(aӞ n1#VK;ˢ/>MqsD5kR'qY^FIZV1Fee%ܙQ#w#;ɽXh#q/&m\$)ufdDy݄h`rK,tzָ!.~ʛ,yZA(-26!!R{#\$(dMN:vIGԫnn,[a(#ZPҪ2c֎!bUO[jiA?\000N?:%l>!9!pԚBF(H`Iec}l?a/!X7 ڕ/|Xm`h\$oe)~MPymD!s~4g TzI\000NXDi٩E8nm?g<̡p°pZ\t{v`gS&k)СA.)aCRA:K1sn:\000\\\$\000tDbOe
PiwY3O\"NhQXM*=*u!*oy;n/L 
6lYjq\t=3̓\000AB9\000CD
\000NP,H/G\"AE/\000]I9`=\toME[XKU\\|R
7Bܣ00ic~^̨nW%4jvQߋ^C\$\000\$6\\(K+6I}7rV}MM;d
\$.RԹc\000\$j/U9ɣKG`.;.̭`ȃ/0q3]rzB379N/\000}Ճas!*7Qg%\\U-,ó29}vbB(h\t`]\000b ctWDФ<E8m'V\000TX\000F&->gw؞;Q\000.\000\000|Y&N7nx!a=;yQ\000hG.\000P>ǵF\000tv۰u\000s*'PL\000\\\0005/\0006_ϲkc6J0=9B.K+#K&PnN})Q&ckٿ:Kg\t+-\000{ks7T*Tꤘ¦\$^7ޢ5m7a./`\000
p[Ja rcgOf#y3yڃ\$ \000HB:Sj9-EZT&ܤ\000\t!Qbî]d1w9cB)i\\P+3@q

A \000׊*_%ݝJmg8Rr[N&)ɁM6vlR!3:.(JY3j`<쁋@-/VJ\000&X2iklܤ5څ8<k5 \000ZwKp)V-=[m&\$\000seLޖ%a\000Hf:K(\" vܼÈ=Y sfYOWY)E2.q~a&h\000B`%\000cHG&%aeDm2v8rIJ(L!FQ(!(\$Lv0b{j!!Rc\\d-t\t} J\tlĨ`xa[\t)e6}YC5)D
B[E(BN+c=^\\-QljKַƼQC=J)-IX&f`
vWhp\000\"gSu!4eNbr~n^=7qnUY0GLN B-uG֔Ftukk0\\\$,\\K2rE2\$ٌ to>!fvD,us33gThwԙd/%b>GuE)L⃑?\t)ݖh\t/e]av]\$s4dm>~r^TpF/R\"T8\$
\"+:\000|l[.ZoOwl#ˡ}.ckȔ%ڤ#%\$%sY(nTyɤF)dhˉc^2b!'Qu\tּObE4\000;I7T1bd4)p'x@IH8x=ђ18,\tB-)lZ\tgԲRJKJ(d~\$\taPlBe^=HY
@\$pfC@VQ;(H\000R\"ډ4qh㣜l)\$ADQPw30ks!3o'x o:juXh\$VTnN`ێsJgXxI\"[\$(J PVl:{&rFrqp2aI#:͢q0P&c귽kъfD
dg#PP@̿
ҋ0,A!ؘ(cV,G9ta
bY\$E@ʾBYoƇeNZ2+{WzX1m?5A`CYL٨+e<T߱l@*Z~JhipJ)QIG̏7iYɞaɩ4Y+Gb7Կ {ʣHwǞ\$#,3}6\$eNUv(qIJm\"N;;Gv_O๋<-V
nl\\Z*Y\t/x7R[znAИgv!P-\000SD-sSR=9w^\000e2ip
,9ڋ\tKUgyf{W)_x^
8?f
mYE?5-}[5(W ǾxA\"^ \$O\t{S\000+:cK53%~,9kѻ,}z
Ǯf!'
 a*}m}-X715<p6ɚ6~aB*qLd\\\\N`&0
{c~&V&.
z+9HvngÅNԭ
JiZڒH{xJY<\\ldlY
@*4iC;&\\\$/T/~A0?|ǍTzMlqe\"[pZ2͑z({\"VK\000{d3sbGu#Dwrh߾r1*<,C\"l_*(sլLfr1\t6^u`4ʐc<wjоmFw)%έz
uHYAr|L6A5FFcyzޡ[rq\"7
D5UYwQs \"Y73#l̺ECDype\$14G5=4.2CP:Og+Cb
nMMX*4j
)ddG|il\000YE\000ݻz}}gKPa;q=B՞{>f-XЭA\000aYo5r'a2}b'k Z_QaoXCeܼGGW@VTnũS#F\"긺B`z\tƽ\000\t_a:`N9Wh\";G-О7Fن؞F8m?Ȟ)ig\t!:X+}<U7l(ĭ2 Ô-tQA}©a\\!sF/Bi/},W;oѲ脍`n=q#Ƴoeʘ-].tQ!Ytg\00028*rB4Xivfxn?6LtKtbC&i3)Lpa7á8T5
gAՂL0 !ӭ6y6sxd_&A\000h.ʊ_r@)V3](D*0b؇^l`у>@''¦E=
̠j;z+\0004}v+A>Ppt[5Z0em\000ڸOƓG5LzsHTzCR6R&`uv2>i^5H'Z@\$yS\t}I&[k{t'PC.}Pf*&!\\gA
վdXR[{L\$\000cB9U\000ar31qL{d_(}ߌ<WpβlI#\t\$w{Q/~wh4)mBOO)Dxg(
+6h3ɆᄛsVʩbW3d\tWk6@|HYg{1[o޼OVSp)_\"pI^ )Id_ /a>LVcjD=iwaFSWerFïǒ&Ɋ_<0s+s9_`龡/fV7Lw^spJY쐎\"u05r^M/
-HTA<
h̴0+.J-6G;8V.&X0;da_|\"멽#N:Z`GJ2Lh>?}SRvuHsEE.AzĴ|Vg2j?~^Jm;
܍81magPye#%ޘڻ9֡4~M^s&qtxsOO2W+Po_o`7KPs2B&Cz^6oMjh\"PM9D_xSƱ'd>w-טFg1EF.g_cpjoҋZIKDWvxaF^ҚI߭0*V⅟.e1dϳǆkq\tͭeYΏ}ȩg9-!GYZj
7ΓRGni\$k#lG#|K5r0wŚ{ȑD\tqPe,=粮\\\$AZVw^6|®ou
sIۂoc]P
ZﱮUW_~կUW-\\`Q38xD\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/NotificationBundle/Assets/img/OneSignal.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/NotificationBundle/Assets/img/OneSignal.png", "/var/www/mautic-ktn/app/bundles/NotificationBundle/Assets/img/OneSignal.png");
    }
}

==> mauticGIT-Test-20260116_092227.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/f3/f3a763a9d8ba284d59471d00f19b3f8b.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/NotificationBundle/Assets/img/OneSignal.png */
class __TwigTemplate_9e765908843e27e3aceb4d276693f52c extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000\000\000\000\000\000\000>a\000\000\$FIDATx]e>\"`AQZ(RػݝfA&EJC0D  (J\t\tHH){w!\$\$tw{;{RngPW_~կUW_kUHjYv<OܷyW|n.Ϸ{}_*w~PO3Jܦ;PkyCç56Wpl{/lDs֧Euuo6=^P\000gCpf@qAO17\\sV#6,k|:xV<;W9̌Tys`/?n06klv`Mn).Iܥk[K\"spC#x!Nظľ}ׯ\\U{[Z&v<e2#BƼE͘S
{xx2T0gk.t`6Ǩ6hd6)LfIb`{kKsp;jg3noM\t?V>j/cSpC])}?и`ߒ7Z\0004Q3z\$pk9Ƴݽ7]Mu<T+XRlD搼NM~+\000SS}[](DshuZ-6_,@+d&۟MpͧCǜXuhW]<t\"S܊nú,^/85Z{6/:v;mgsI'P68
\000,ZohJ4</lO_!>a
w~ّ^\000tzۂR?C=lS\$/clu%kӆ#E2AGCq:KM67ڔO>6@ZolYPdẍLsz*ǩUz.ohY0곾`'6Ң5g'_=82yt|\"`1KڞrG,]X3r37*T8GZ?n
|WRr}m^V=em31bͨ}ys{[AT/o^K!Je2{Rz]/'S/P%mޠPAzpφç<XW2+0_}:qSꇈ︿](wW˯.bg\"Z@{V
(Uw:&ζRot\000Qx-x5&ខIP\tunnp.KV֨cKO-UAu4
ޭPO6o=G_8cN2?pE>Z
/~yWJxp\tI W6#u8'pl`LA9p)OڦɳmCs}k4>sr
ZR[2DYw&mɏ!6oL.'l?iw1LTM;d}ɠugc!NiB9\" :\t\\ABV)d%\"s6ǐH(8L;,B!4) :G2g.+37ƽ}vosu5ZR?IlJ2h6ӳځ@~\$~բ\0000H+IU1el@Ah=g6/NMRivٱGMѻewt+C>Q7\"[!Vuqu˜VmǷL#N6f[2Y.߇1./zL\"foYGw47oU1hYl(FI'V|=/7Y6S~OsxYqshB8Ċl\$w'+0.j6=~XHm :(Uro:Sn:l\tN,+o;llͺ3ɴPPk~ȸCkv
ZͦUp<X)9D>pj'Xֆ=)|_[zEOa^-mGGx~G#a(5\"3\\\t%O0RQzjk6b]I4Q1,?{zI<e8aVȨ
:w|e|l1wgE谬[<r\"\t2smU`/l#aʪR킭e̝T:\\}tm2sh&\\Ӛg(LC_4jDb^_rB\000Jd
JȞl\000%6oni}iڙa
b\000B`&7x~:#:d#;9,u[\000^0pfDuob0N?y;,PwQoWvg-My[](JGXX
w6
^\\l툫ZIq,61cY
>ṇI`xZTj?z&8QD|eބ3-<q%lI6m>Er_SkkWnv@}iC1O\000rP\\,81SɚCx}Ο|tdWL6:u<fQqRPÙ&Zʙm~U6
6g<j;:|_O*@鸎oS55A43
~sp\\m!C?<fIQY&,[ʼB'զy[N{\$kݎMhDH6a5Ę\"u^!1ܧ2)rsQICxI6U]63*;X6%) !S\"f=\$ٓ^z8*a\tT1xq+\t+Xhjyu\000hӉgx
!dԴ##)%췸\tWY)\$WOѲvٸ&)`Evwۘ`Ώsz͏l+(KK0nMĘR_A*If`جv\t45Ԅ>
?LX\000x'osSh\"ݰ®Bu%WAl{7,/cϚH5[J~?sΟe%(rfŦsA/gn<N:Bpݵ/NFh>Ƣݴz
xpV;Ew`T46/)e
kPT*+Ԏ>@%\tz\tkT3\tRSGܚ0*gŦPz6v)m,;p~C
2pkeu|@s%9ܼ6\$cnIA;0;'\$5r
ܬ\$?B**,D5ƓY÷
+ \">/\\CRlߏe\t]*:hзD4d!'=m^'q#\000CƳR/rz;ߣtڠ)k'=2=ͿH1{ȓڣ*R5\$20S\"oLOBe.'Gp8ԼQpy.%C@ʻt\000{Ήx4\\dXy{
*:f-~>P?vZ4`;=-[iXZ\\639-fg.JIoe_0B
LkK!f@R;|]I!DG-2 zjZ&K\"OG7M8-S<²
?5\000B7;r\tr\"\000J /MÑ#Cّx(aӞ n1#VK;ˢ/>MqsD5kR'qY^FIZV1Fee%ܙQ#w#;ɽXh#q/&m\$)ufdDy݄h`rK,tzָ!.~ʛ,yZA(-26!!R{#\$(dMN:vIGԫnn,[a(#ZPҪ2c֎!bUO[jiA?\000N?:%l>!9!pԚBF(H`Iec}l?a/!X7 ڕ/|Xm`h\$oe)~MPymD!s~4g TzI\000NXDi٩E8nm?g<̡p°pZ\t{v`gS&k)СA.)aCRA:K1sn:\000\\\$\000tDbOe
PiwY3O\"NhQXM*=*u!*oy;n/L 
6lYjq\t=3̓\000AB9\000CD
\000NP,H/G\"AE/\000]I9`=\toME[XKU\\|R
7Bܣ00ic~^̨nW%4jvQߋ^C\$\000\$6\\(K+6I}7rV}MM;d
\$.RԹc\000\$j/U9ɣKG`.;.̭`ȃ/0q3]rzB379N/\000}Ճas!*7Qg%\\U-,ó29}vbB(h\t`]\000b ctWDФ<E8m'V\000TX\000F&->gw؞;Q\000.\000\000|Y&N7nx!a=;yQ\000hG.\000P>ǵF\000tv۰u\000s*'PL\000\\\0005/\0006_ϲkc6J0=9B.K+#K&PnN})Q&ckٿ:Kg\t+-\000{ks7T*Tꤘ¦\$^7ޢ5m7a./`\000
p[Ja rcgOf#y3yڃ\$ \000HB:Sj9-EZT&ܤ\000\t!Qbî]d1w9cB)i\\P+3@q

A \000׊*_%ݝJmg8Rr[N&)ɁM6vlR!3:.(JY3j`<쁋@-/VJ\000&X2iklܤ5څ8<k5 \000ZwKp)V-=[m&\$\000seLޖ%a\000Hf:K(\" vܼÈ=Y sfYOWY)E2.q~a&h\000B`%\000cHG&%aeDm2v8rIJ(L!FQ(!(\$Lv0b{j!!Rc\\d-t\t} J\tlĨ`xa[\t)e6}YC5)D
B[E(BN+c=^\\-QljKַƼQC=J)-IX&f`
vWhp\000\"gSu!4eNbr~n^=7qnUY0GLN B-uG֔Ftukk0\\\$,\\K2rE2\$ٌ to>!fvD,us33gThwԙd/%b>GuE)L⃑?\t)ݖh\t/e]av]\$s4dm>~r^TpF/R\"T8\$
\"+:\000|l[.ZoOwl#ˡ}.ckȔ%ڤ#%\$%sY(nTyɤF)dhˉc^2b!'Qu\tּObE4\000;I7T1bd4)p'x@IH8x=ђ18,\tB-)lZ\tgԲRJKJ(d~\$\taPlBe^=HY
@\$pfC@VQ;(H\000R\"ډ4qh㣜l)\$ADQPw30ks!3o'x o:juXh\$VTnN`ێsJgXxI\"[\$(J PVl:{&rFrqp2aI#:͢q0P&c귽kъfD
dg#PP@̿
ҋ0,A!ؘ(cV,G9ta
bY\$E@ʾBYoƇeNZ2+{WzX1m?5A`CYL٨+e<T߱l@*Z~JhipJ)QIG̏7iYɞaɩ4Y+Gb7Կ {ʣHwǞ\$#,3}6\$eNUv(qIJm\"N;;Gv_O๋<-V
nl\\Z*Y\t/x7R[znAИgv!P-\000SD-sSR=9w^\000e2ip
,9ڋ\tKUgyf{W)_x^
8?f
mYE?5-}[5(W ǾxA\"^ \$O\t{S\000+:cK53%~,9kѻ,}z
Ǯf!'
 a*}m}-X715<p6ɚ6~aB*qLd\\\\N`&0
{c~&V&.
z+9HvngÅNԭ
JiZڒH{xJY<\\ldlY
@*4iC;&\\\$/T/~A0?|ǍTzMlqe\"[pZ2͑z({\"VK\000{d3sbGu#Dwrh߾r1*<,C\"l_*(sլLfr1\t6^u`4ʐc<wjоmFw)%έz
uHYAr|L6A5FFcyzޡ[rq\"7
D5UYwQs \"Y73#l̺ECDype\$14G5=4.2CP:Og+Cb
nMMX*4j
)ddG|il\000YE\000ݻz}}gKPa;q=B՞{>f-XЭA\000aYo5r'a2}b'k Z_QaoXCeܼGGW@VTnũS#F\"긺B`z\tƽ\000\t_a:`N9Wh\";G-О7Fن؞F8m?Ȟ)ig\t!:X+}<U7l(ĭ2 Ô-tQA}©a\\!sF/Bi/},W;oѲ脍`n=q#Ƴoeʘ-].tQ!Ytg\00028*rB4Xivfxn?6LtKtbC&i3)Lpa7á8T5
gAՂL0 !ӭ6y6sxd_&A\000h.ʊ_r@)V3](D*0b؇^l`у>@''¦E=
̠j;z+\0004}v+A>Ppt[5Z0em\000ڸOƓG5LzsHTzCR6R&`uv2>i^5H'Z@\$yS\t}I&[k{t'PC.}Pf*&!\\gA
վdXR[{L\$\000cB9U\000ar31qL{d_(}ߌ<WpβlI#\t\$w{Q/~wh4)mBOO)Dxg(
+6h3ɆᄛsVʩbW3d\tWk6@|HYg{1[o޼OVSp)_\"pI^ )Id_ /a>LVcjD=iwaFSWerFïǒ&Ɋ_<0s+s9_`龡/fV7Lw^spJY쐎\"u05r^M/
-HTA<
h̴0+.J-6G;8V.&X0;da_|\"멽#N:Z`GJ2Lh>?}SRvuHsEE.AzĴ|Vg2j?~^Jm;
܍81magPye#%ޘڻ9֡4~M^s&qtxsOO2W+Po_o`7KPs2B&Cz^6oMjh\"PM9D_xSƱ'd>w-טFg1EF.g_cpjoҋZIKDWvxaF^ҚI߭0*V⅟.e1dϳǆkq\tͭeYΏ}ȩg9-!GYZj
7ΓRGni\$k#lG#|K5r0wŚ{ȑD\tqPe,=粮\\\$AZVw^6|®ou
sIۂoc]P
ZﱮUW_~կUW-\\`Q38xD\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/NotificationBundle/Assets/img/OneSignal.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/NotificationBundle/Assets/img/OneSignal.png", "/var/www/html/mauticGIT-Test/app/bundles/NotificationBundle/Assets/img/OneSignal.png");
    }
}
